# Knowledge Data Analysis and Processing Platform
This library contains a collection of utilities for efficiently processing and anlyzing the data of Wiki-based and QnA-based portals (eg., Wikipedia, Wikia, Stack Exchange, etc.). The function takes Knol-ML files as input. Most of the functions of this library are implemented in such a way that parallel processing can be achieved.

The library is currently in the development phase, feel free to raise an issue. We welcome the community to contribute towards KDAP code base and ARK dataset.
Please check our webpage for more details [GitHub Page](https://kdap.github.io/)

# Knol-ML data dump

The data dump can be found [here](https://archive.org/details/KnolML)
